@@ -115,6 +115,10 @@ class BaseCommand(
         A silent command will call the actor ``write`` method with ``silent=True``,
         which will update the internal model and record all the output replies but
         will not write them to the users.
+    internal
+        A silent command will call the actor ``write`` method with ``internal=True``,
+        which will instruct the actor to add the internal flag to the header of the
+        reply.
     time_limit
         Time out the command if it has been running for this long.
     loop
@@ -134,10 +138,10 @@ class BaseCommand(
         call_now: bool = False,
         default_keyword: str = "text",
         silent: bool = False,
+        internal: bool = False,
         time_limit: float | None = None,
         loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
-
         self.commander_id = commander_id
         self.consumer_id = consumer_id
         self.command_id = command_id
@@ -148,6 +152,7 @@ class BaseCommand(
         self.parent = parent
 
         self.silent = silent
+        self.internal = internal
 
         self._reply_callback = reply_callback
 
@@ -245,7 +250,6 @@ class BaseCommand(
             raise TypeError(f"Status {status!r} is not a valid command status.")
 
         if status != self._status:
-
             status_code = status.code
             if status_code is None:
                 raise ValueError(f"Invalid status code {status_code!r}.")
@@ -306,7 +310,7 @@ class BaseCommand(
 
     def write(
         self,
-        message_code: str | int = "i",
+        message_code: clu.base.MessageCode | str | int = clu.base.MessageCode.INFO,
         message: Optional[Union[Dict[str, Any], str]] = None,
         broadcast: bool = False,
         **kwargs,
@@ -355,18 +359,22 @@ class BaseCommand(
             else:
                 raise ValueError(f"Invalid message code {message_code}.")
 
+        message_code = clu.base.MessageCode(message_code)
+
         # If the parent has a command, do not output : or f since it would
         # confuse the stream and potentially Tron.
         if self.parent:
-            if message_code == ">":
+            if message_code == clu.base.MessageCode.STARTED:
                 # The parent is already running and > never includes a message.
                 return
-            if message_code == ":":
-                message_code = "i"
+            if message_code == clu.base.MessageCode.DONE:
+                message_code = clu.base.MessageCode.INFO
                 if kwargs == {} and (message == {} or not message):
                     return
-            elif message_code == "f":
-                message_code = "e"
+            elif message_code == clu.base.MessageCode.FAILED:
+                message_code = clu.base.MessageCode.ERROR
+
+        internal = kwargs.pop("internal", self.internal)
 
         self.actor.write(
             message_code,
@@ -374,6 +382,7 @@ class BaseCommand(
             command=command,
             broadcast=broadcast,
             silent=self.silent,
+            internal=internal,
             **kwargs,
         )
 
@@ -417,7 +426,6 @@ class Command(BaseCommand[Actor_co, "Command"]):
         transport: Optional[Any] = None,
         **kwargs,
     ):
-
         BaseCommand.__init__(self, **kwargs)
 
         #: The raw command string.
@@ -525,7 +533,6 @@ class TimedCommandList(list):
         resolution=0.5,
         loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
-
         self.resolution = resolution
         self.actor = actor
         self.loop = loop or asyncio.get_event_loop()
@@ -546,7 +553,6 @@ class TimedCommandList(list):
         first_time = True
 
         while True:
-
             for timed_command in self:
                 elapsed = current_time - timed_command.last_run
                 if first_time or elapsed > timed_command.delay:
@@ -609,7 +615,6 @@ class TimedCommand(object):
     """
 
     def __init__(self, command_string: str, delay: float = 1, first_silent=False):
-
         self.command_string = command_string
         self.delay = delay
 
@@ -646,7 +651,6 @@ class FakeCommand(BaseCommand):
     """A fake command that output to a logger."""
 
     def __init__(self, log: logging.Logger, actor=None):
-
         self.log = log
 
         super().__init__(actor=actor)
@@ -657,7 +661,6 @@ class FakeCommand(BaseCommand):
         message: Optional[Union[Dict[str, Any], str]] = None,
         **kwargs,
     ):
-
         if message_code == "d":
             level = logging.DEBUG
         elif message_code == "i":
