@@ -15,15 +15,18 @@ import warnings
 
 from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union, cast
 
+import click
+
 import clu
+from clu.parsers.click import CluCommand
 
 from ..actor import CustomTransportType
-from ..base import BaseActor, Reply
+from ..base import BaseActor, MessageCode, Reply
 from ..command import Command, TimedCommandList, parse_legacy_command
 from ..parsers import ClickParser
 from ..protocol import TCPStreamServer
 from ..tools import log_reply
-from .tron import TronConnection, tron_reconnect
+from .tron import TronConnection
 from .types.messages import Reply as OpsReply
 
 
@@ -34,6 +37,23 @@ T = TypeVar("T", bound="BaseLegacyActor")
 PathLike = Union[str, pathlib.Path]
 
 
+@click.command(cls=CluCommand)
+async def tron_reconnect(*args):
+    """Reconnects to tron/hub."""
+
+    command = args[0]
+
+    if command.actor.tron is None:
+        return command.fail("Tron instance not set.")
+
+    command.actor.tron.stop()
+    await asyncio.sleep(0.5)
+
+    await command.actor.tron.start()
+
+    return command.finish()
+
+
 class BaseLegacyActor(BaseActor):
     """An actor that provides compatibility with the SDSS opscore protocol.
 
@@ -102,7 +122,6 @@ class BaseLegacyActor(BaseActor):
         additional_properties: bool = False,
         config: Dict[str, Any] = {},
     ):
-
         super().__init__(
             name,
             version=version,
@@ -267,14 +286,14 @@ class BaseLegacyActor(BaseActor):
     def format_user_output(
         user_id: int,
         command_id: int,
-        message_code: str,
+        message_code: MessageCode,
         msg_str: Optional[str] = None,
     ) -> str:
         """Formats a string to send to users."""
 
         msg_str = "" if msg_str is None else " " + msg_str
 
-        return f"{user_id} {command_id:d} {message_code:s}{msg_str:s}"
+        return f"{user_id} {command_id:d} {message_code.value:s}{msg_str:s}"
 
     def show_new_user_info(self, user_id: int):
         """Shows information for new users. Called when a new user connects."""
@@ -409,7 +428,7 @@ class BaseLegacyActor(BaseActor):
 
     def write(
         self,
-        message_code: str = "i",
+        message_code: MessageCode | str = "i",
         message: Optional[Dict[str, Any]] = None,
         command: Optional[Command] = None,
         user_id: int = 0,
@@ -452,6 +471,8 @@ class BaseLegacyActor(BaseActor):
             supersedes ``message``.
         """
 
+        message_code = MessageCode(message_code)
+
         reply = BaseActor.write(
             self,
             message_code=message_code,
@@ -459,7 +480,7 @@ class BaseLegacyActor(BaseActor):
             command=command,
             broadcast=broadcast,
             validate=validate,
-            call_internal=False,
+            emit=False,
             expand_exceptions=False,
             **kwargs,
         )
@@ -533,7 +554,6 @@ class LegacyActor(ClickParser, BaseLegacyActor):
     """A legacy actor that uses the `.ClickParser`."""
 
     def __init__(self, *args, **kwargs):
-
         super().__init__(*args, **kwargs)
 
         if self.tron:
