@@ -21,7 +21,6 @@ import clu.base
 from clu.command import Command, CommandStatus
 from clu.exceptions import CluWarning
 from clu.model import BaseModel, Property
-from clu.parsers.click import command_parser
 from clu.protocol import ReconnectingTCPClientProtocol
 
 from .types.keys import Key, KeysDictionary
@@ -32,23 +31,6 @@ from .types.parser import ParseError, ReplyParser
 __all__ = ["TronConnection", "TronModel", "TronKey"]
 
 
-@command_parser.command(name="tron-reconnect")
-async def tron_reconnect(*args):
-    """Pings the actor."""
-
-    command = args[0]
-
-    if command.actor.tron is None:
-        return command.fail("Tron instance not set.")
-
-    command.actor.tron.stop()
-    await asyncio.sleep(0.5)
-
-    await command.actor.tron.start()
-
-    return command.finish()
-
-
 class TronKey(Property):
     """A Tron model key with callbacks.
 
@@ -64,7 +46,6 @@ class TronKey(Property):
         model: Optional[TronModel] = None,
         callback: Optional[Callable[[TronKey], Any]] = None,
     ):
-
         initial_value = [None] * len(key.typedValues.vtypes)
         super().__init__(name, value=initial_value, model=model, callback=callback)
 
@@ -108,7 +89,6 @@ class TronModel(BaseModel[TronKey]):
         keydict: KeysDictionary,
         callback: Optional[Callable[[TronModel], Any]] = None,
     ):
-
         super().__init__(keydict.name, callback=callback)
 
         self.keydict = keydict
@@ -134,7 +114,6 @@ class TronModel(BaseModel[TronKey]):
 
         with self._lock:
             for reply_key in reply.keywords:
-
                 self.last_seen = time.time()
 
                 key_name = reply_key.name.lower()
@@ -213,7 +192,6 @@ class TronConnection(clu.base.BaseClient):
         models: List[str] = [],
         **kwargs,
     ):
-
         super().__init__(name, **kwargs)
 
         self.commander = commander
@@ -290,7 +268,6 @@ class TronConnection(clu.base.BaseClient):
         return False
 
     async def run_forever(self):  # pragma: no cover
-
         assert self.protocol and self.connected()
 
         # Keep alive until the connection is closed.
@@ -380,12 +357,10 @@ class TronConnection(clu.base.BaseClient):
         n_keys = 10
 
         for model in self.models.values():
-
             actor = model.name
             keys = [key.lower() for key in model]
 
             for ii in range(0, len(keys), n_keys):
-
                 keys_to_request = keys[ii : ii + n_keys]
 
                 if len(keys_to_request) == 0:
