@@ -63,6 +63,7 @@ DEFAULT_SCHEMA = {
         "items": [{"type": "integer"}, {"type": "string"}],
     },
     "num_users": {"type": "integer"},
+    "command_model": {"oneOf": [{"type": "array"}, {"type": "object"}]},
 }
 
 
@@ -91,7 +92,6 @@ class Property(CallbackMixIn):
         model: Optional[Any] = None,
         callback: Optional[Callable[[Any], Any]] = None,
     ):
-
         self.name = name
         self._value = value
         self.last_seen: float | None = None
@@ -150,7 +150,6 @@ class BaseModel(CaseInsensitiveDict[T], CallbackMixIn):
     """
 
     def __init__(self, name: str, callback: Optional[Callable[[Any], Any]] = None):
-
         self.name = name
         self.last_seen = None
 
@@ -210,7 +209,6 @@ class Model(BaseModel[Property]):
         additional_properties: bool = False,
         **kwargs,
     ):
-
         if is_file:
             schema = cast(PathLike, schema)
             schema = open(pathlib.Path(schema).expanduser(), "r").read()
@@ -361,7 +359,6 @@ class ModelSet(dict):
         raise_exception: bool = True,
         **kwargs,
     ):
-
         dict.__init__(self, {})
 
         self.client = client
@@ -371,34 +368,40 @@ class ModelSet(dict):
         self.__get_schema_command = get_schema_command
         self.__kwargs = kwargs
 
+    async def add_actor(self, actor: str):
+        """Adds an actor schema."""
+
+        schema = None
+
+        try:
+            cmd = await self.client.send_command(
+                actor,
+                self.__get_schema_command,
+                internal=True,
+            )
+            await cmd
+
+            if cmd.status.did_fail:
+                raise CluError(f"Failed getting schema for {actor}.")
+            else:
+                for reply in cmd.replies:
+                    if "schema" in reply.message:
+                        schema = json.loads(reply.message["schema"])
+                        break
+                if schema is None:
+                    raise CluError(f"{actor} did not reply with a model.")
+
+            self[actor] = Model(actor, schema, **self.__kwargs)
+
+        except Exception as err:
+            if not self.__raise_exception:
+                warnings.warn(f"Cannot load model {actor!r}. {err}", CluWarning)
+                return
+            raise
+
     async def load_schemas(self, actors: Optional[List[str]] = None):
         """Loads the actor schames."""
 
         actors = actors or self.actors or []
-        schema = None
-
         for actor in actors:
-
-            try:
-
-                cmd = await self.client.send_command(actor, self.__get_schema_command)
-                await cmd
-
-                if cmd.status.did_fail:
-                    raise CluError(f"Failed getting schema for {actor}.")
-                else:
-                    for reply in cmd.replies:
-                        if "schema" in reply.message:
-                            schema = json.loads(reply.message["schema"])
-                            break
-                    if schema is None:
-                        raise CluError(f"{actor} did not reply with a model.")
-
-                self[actor] = Model(actor, schema, **self.__kwargs)
-
-            except Exception as err:
-
-                if not self.__raise_exception:
-                    warnings.warn(f"Cannot load model {actor!r}. {err}", CluWarning)
-                    continue
-                raise
+            await self.add_actor(actor)
