@@ -20,6 +20,7 @@ from typing import Any, List, TypeVar
 
 import click
 from click.decorators import group, pass_obj
+from unclick.core import command_to_json
 
 from sdsstools.logger import SDSSLogger
 
@@ -133,7 +134,6 @@ class CluCommand(click.Command):
     """Override :py:class:`click.Command` to pass the actor and command."""
 
     def __init__(self, *args, context_settings=None, **kwargs):
-
         # Unless told otherwise, set ignore_unknown_options=True to prevent
         # negative numbers to be considered as options. See #40.
         if context_settings is None or "ignore_unknown_options" not in context_settings:
@@ -141,6 +141,7 @@ class CluCommand(click.Command):
             context_settings["ignore_unknown_options"] = True
 
         self.cancellable = kwargs.pop("cancellable", False)
+        self.internal = kwargs.pop("internal", None)
 
         if self.cancellable is True:
             kwargs["params"].append(
@@ -173,7 +174,10 @@ class CluCommand(click.Command):
         """Schedules the callback as a task with a timeout."""
 
         parser_args = ctx.obj.get("parser_args", [])
+
         command = parser_args[0] if len(parser_args) > 0 else None
+        if command is not None and self.internal is not None:
+            command.internal = self.internal
 
         callback_task = asyncio.create_task(
             ctx.invoke(self.callback, *parser_args, **ctx.params)
@@ -202,9 +206,7 @@ class CluCommand(click.Command):
         """As :py:class:`click.Command.invoke` but passes the actor and command."""
 
         if self.callback is not None:
-
             with ctx:
-
                 loop = asyncio.get_event_loop()
 
                 ctx.obj["parser_args"][0].context = ctx
@@ -231,14 +233,14 @@ class CluCommand(click.Command):
                 )
 
                 # Launches callback scheduler and adds the done callback
-                ctx.task = loop.create_task(
+                ctx.task = loop.create_task(  # type: ignore
                     self._schedule_callback(ctx, timeout=timeout)
                 )
 
                 ctx.task._command_name = self.full_path  # type: ignore For PY<38
                 ctx.task._date = time.time()  # type: ignore
 
-                ctx.task.add_done_callback(done_callback)
+                ctx.task.add_done_callback(done_callback)  # type: ignore
 
                 # Add some attributes to the task because it's
                 # what will be passed to done_callback
@@ -300,7 +302,6 @@ class CluGroup(click.Group):
         return decorator
 
     def parse_args(self, ctx, args):  # pragma: no cover
-
         # Copy this method so that we can turn off the printing of the
         # usage before ctx.exit()
         if not args and self.no_args_is_help and not ctx.resilient_parsing:
@@ -341,7 +342,6 @@ def timeout(seconds: float):
     """A decorator to timeout the command after a number of ``seconds``."""
 
     def decorator(f):
-
         # This is a bit of a hack but we cannot access the context here so
         # we add the timeout directly to the callback function.
         f.timeout = seconds
@@ -361,7 +361,6 @@ def unique():
     def decorator(f):
         @functools.wraps(f)
         async def new_func(command, *args, **kwargs):
-
             ctx = click.get_current_context()
 
             subcmd = ctx.invoked_subcommand or ""
@@ -451,7 +450,6 @@ def help_(ctx, *args, parser_command):
 
     # Gets the help lines for the command group or for a specific command.
     if len(parser_command) > 0:
-
         ctx_commands = ctx.command.commands
 
         for ii in range(len(parser_command)):
@@ -468,7 +466,6 @@ def help_(ctx, *args, parser_command):
                 ctx_commands = ctx_command.commands
 
     else:
-
         help_lines: str = ctx.get_help()
 
     message = []
@@ -488,6 +485,36 @@ def help_(ctx, *args, parser_command):
         return command.finish()
 
 
+@command_parser.command(internal=True)
+@click.argument("COMMAND-NAME", type=str, required=False)
+@click.pass_context
+def get_command_model(
+    ctx: click.Context,
+    command: Command,
+    *args,
+    command_name: str | None = None,
+):
+    """Returns a dictionary representation of the command using ``unclick``."""
+
+    from ..legacy import LegacyActor
+
+    click_command = ctx.command
+    assert isinstance(click_command, CluGroup)
+
+    if command_name is not None:
+        click_command = click_command.commands.get(command_name, None)
+        if not click_command:
+            return command.fail(f"Cannot find command {command_name}.")
+
+    model_str = command_to_json(click_command)
+    model_dict = json.loads(model_str)
+
+    if isinstance(command.actor, LegacyActor):
+        return command.finish(command_model=model_str)
+
+    return command.finish(command_model=model_dict)
+
+
 @command_parser.command(name="keyword")
 @click.argument("KEYWORD", type=str, required=True)
 def keyword(command, *args, keyword):
@@ -544,7 +571,7 @@ class ClickParser:
             return command
 
         assert command.status
-        command.set_status(command.status.RUNNING)
+        command.set_status(command.status.RUNNING, internal=True)
 
         # If the command contains the --help flag,
         # redirects it to the help command.
@@ -591,11 +618,9 @@ class ClickParser:
         """Handles an exception during parsing or execution of a command."""
 
         try:
-
             raise exception
 
-        except (click.ClickException) as ee:
-
+        except click.ClickException as ee:
             ctx = command.ctx
             message = ""
 
@@ -620,12 +645,10 @@ class ClickParser:
                 command.write("e", error=msg)
 
         except (click.exceptions.Exit, click.exceptions.Abort):
-
             if not command.status.is_done:
                 command.fail(error=f"Command {command.body!r} was aborted.")
 
         except Exception as err:
-
             msg = (
                 f"Command {command.body!r} failed because of an uncaught "
                 f"error '{err.__class__.__name__}: {str(err)}'. See "
